BaiduAdInteractionCallBack class

插屏广告回调

Constructors

BaiduAdInteractionCallBack({BDOnShow? onShow, BDOnClick? onClick, BDOnClose? onClose, BDOnFail? onFail, BDOnReady? onReady, BDOnUnReady? onUnReady})

Properties

hashCode int
The hash code for this object.
no setterinherited
onClick BDOnClick?
getter/setter pair
onClose BDOnClick?
getter/setter pair
onFail BDOnFail?
getter/setter pair
onReady BDOnClick?
getter/setter pair
onShow BDOnClick?
getter/setter pair
onUnReady BDOnClick?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited