BaiduAdMethod class

Constructors

BaiduAdMethod()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

onAdMethod → const String
stream中 广告方法
onClick → const String
点击
onClose → const String
广告关闭
onFail → const String
加载失败
onReady → const String
广告预加载完成
onShow → const String
广告加载状态 view使用 显示view
onSkip → const String
跳过
onUnReady → const String
广告未预加载
onVerify → const String
广告奖励校验