Baiduad class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
getSDKVersion()
→ Future<String>
-
获取SDK版本号
-
loadInterstitialAd({required String androidId, required String iosId})
→ Future<bool>
-
预加载插屏广告(智选模版)
-
loadRewardAd({required String androidId, required String iosId, String? appSid, required String rewardName, required int rewardAmount, required String userId, String? customData, bool? useSurfaceView, bool? isShowDialog, bool? useRewardCountdown})
→ Future<bool>
-
激励视频广告预加载
-
privacy({bool? readDeviceID, bool? appList, bool? location, bool? storage, bool? personalAds, bool? bDPermission})
→ Future<bool>
-
隐私敏感权限API&限制个性化广告推荐
-
register({required String androidAppId, required String iosAppId, bool? debug})
→ Future<bool>
-
SDK注册初始化
androidAppId andorid广告id
-
showInterstitialAd()
→ Future<bool>
-
显示插屏广告(百度优选)
-
showRewardVideoAd()
→ Future<bool>
-
显示激励广告